@@ -31,11 +31,26 @@ from PIL import Image, ImageFilter
         show_default=True,
         help='Radius of GaussianBlur'
         )
-def blur(inputimage, outputimage, radius):
+@click.option(
+        '-t',
+        '--opacity',
+        type=click.FLOAT,
+        default=1,
+        show_default=True,
+        help="Opacity of bluredimage"
+        )
+def blur(inputimage, outputimage, radius, opacity):
     inputimage = Image.open(inputimage)
     bluredimage = inputimage.filter(ImageFilter.GaussianBlur(radius))
-    bluredimage.save(outputimage, format="png")
 
+    datas = bluredimage.getdata()
+    newData = []
+    for item in datas:
+        newData.append([item[0], item[1], item[2], t*item[3]])
+
+    bluredimage.putdata(newData)
+    
+    bluredimage.save(outputimage, format="png")
     click.echo(f'{inputimage} is blured to radius {radius} as {outputimage}.')
 
 
